[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [kdepim-runtime/frameworks] /: kDebug--
From:       Montel Laurent <montel () kde ! org>
Date:       2014-06-05 21:34:21
Message-ID: E1WsfIj-0007il-Ps () scm ! kde ! org
[Download RAW message or body]

Git commit a6ee43704bbf50d75054e7c5d03f5c21ac14a421 by Montel Laurent.
Committed on 05/06/2014 at 21:33.
Pushed by mlaurent into branch 'frameworks'.

kDebug--

M  +30   -30   agents/invitations/invitationsagent.cpp
M  +8    -8    resources/pop3/accountdialog.cpp
M  +10   -10   resources/pop3/jobs.cpp
M  +38   -38   resources/pop3/pop3resource.cpp
M  +2    -2    resources/pop3/settings.cpp

http://commits.kde.org/kdepim-runtime/a6ee43704bbf50d75054e7c5d03f5c21ac14a421

diff --git a/agents/invitations/invitationsagent.cpp \
b/agents/invitations/invitationsagent.cpp index 610a893..3cc27e2 100644
--- a/agents/invitations/invitationsagent.cpp
+++ b/agents/invitations/invitationsagent.cpp
@@ -169,7 +169,7 @@ InvitationsAgentItem::~InvitationsAgentItem()
 
 void InvitationsAgentItem::add( const Item &item )
 {
-  kDebug();
+  qDebug();
   const Collection collection = m_agent->collection();
   Q_ASSERT( collection.isValid() );
 
@@ -186,7 +186,7 @@ void InvitationsAgentItem::createItemResult( KJob *job )
   ItemCreateJob *createJob = qobject_cast<ItemCreateJob*>( job );
   m_jobs.removeAll( createJob );
   if ( createJob->error() ) {
-    kWarning() << "Failed to create new Item in invitations collection." << \
createJob->errorText(); +    qWarning() << "Failed to create new Item in invitations \
collection." << createJob->errorText();  return;
   }
 
@@ -201,7 +201,7 @@ void InvitationsAgentItem::createItemResult( KJob *job )
 void InvitationsAgentItem::fetchItemDone( KJob *job )
 {
   if ( job->error() ) {
-    kWarning() << "Failed to fetch Item in invitations collection." << \
job->errorText(); +    qWarning() << "Failed to fetch Item in invitations \
collection." << job->errorText();  return;
   }
 
@@ -220,19 +220,19 @@ void InvitationsAgentItem::fetchItemDone( KJob *job )
 void InvitationsAgentItem::modifyItemDone( KJob *job )
 {
   if ( job->error() ) {
-    kWarning() << "Failed to modify Item in invitations collection." << \
job->errorText(); +    qWarning() << "Failed to modify Item in invitations \
collection." << job->errorText();  return;
   }
 
   //ItemModifyJob *mj = qobject_cast<ItemModifyJob*>( job );
-  //kDebug()<<"Job successful done.";
+  //qDebug()<<"Job successful done.";
 }
 
 InvitationsAgent::InvitationsAgent( const QString &id )
   : AgentBase( id ), AgentBase::ObserverV2()
   , m_invitationsCollection( new InvitationsCollection( this ) )
 {
-  kDebug();
+  qDebug();
 
   changeRecorder()->setChangeRecordingEnabled( false ); // behave like Monitor
   changeRecorder()->itemFetchScope().fetchFullPayload();
@@ -250,7 +250,7 @@ InvitationsAgent::~InvitationsAgent()
 
 void InvitationsAgent::initStart()
 {
-  kDebug();
+  qDebug();
 
   m_invitationsCollection->clear();
   if ( m_invitationsCollection->hasDefaultCollection() ) {
@@ -285,7 +285,7 @@ void InvitationsAgent::initDone( KJob *job )
 {
   if ( job ) {
     if ( job->error() ) {
-      kWarning() << "Failed to request default collection:" << job->errorText();
+      qWarning() << "Failed to request default collection:" << job->errorText();
       return;
     }
 
@@ -312,7 +312,7 @@ KPIMIdentities::IdentityManager* \
InvitationsAgent::identityManager()  
 void InvitationsAgent::configure( WId windowId )
 {
-  kDebug() << windowId;
+  qDebug() << windowId;
   /*
   QWidget *parent = QWidget::find( windowId );
   KDialog *dialog = new KDialog( parent );
@@ -326,11 +326,11 @@ void InvitationsAgent::configure( WId windowId )
 #if 0
 void InvitationsAgent::createAgentResult( KJob *job )
 {
-  kDebug();
+  qDebug();
   AgentInstance agent;
   if ( job ) {
     if ( job->error() ) {
-      kWarning() << job->errorString();
+      qWarning() << job->errorString();
       emit status( AgentBase::Broken, i18n( "Failed to create resource: %1", \
job->errorString() ) );  return;
     }
@@ -347,7 +347,7 @@ void InvitationsAgent::createAgentResult( KJob *job )
                                         KGlobal::dirs()->localxdgdatadir() + \
"akonadi_ical_resource" );  
     if ( !reply.isValid() ) {
-      kWarning() << "dbus call failed, m_resourceId=" << m_resourceId;
+      qWarning() << "dbus call failed, m_resourceId=" << m_resourceId;
       emit status( AgentBase::Broken, i18n( "Failed to set the directory for \
invitations via D-Bus" ) );  AgentManager::self()->removeInstance( agent );
       return;
@@ -371,9 +371,9 @@ void InvitationsAgent::createAgentResult( KJob *job )
 
 void InvitationsAgent::resourceSyncResult( KJob *job )
 {
-  kDebug();
+  qDebug();
   if ( job->error() ) {
-    kWarning() << job->errorString();
+    qWarning() << job->errorString();
     emit status( AgentBase::Broken, i18n( "Failed to synchronize collection: %1", \
job->errorString() ) );  if ( newAgentCreated )
       AgentManager::self()->removeInstance( AgentManager::self()->instance( \
m_resourceId ) ); @@ -388,10 +388,10 @@ void InvitationsAgent::resourceSyncResult( \
KJob *job )  
 void InvitationsAgent::collectionFetchResult( KJob *job )
 {
-  kDebug();
+  qDebug();
 
   if ( job->error() ) {
-    kWarning() << job->errorString();
+    qWarning() << job->errorString();
     emit status( AgentBase::Broken, i18n( "Failed to fetch collection: %1", \
job->errorString() ) );  if ( newAgentCreated )
       AgentManager::self()->removeInstance( AgentManager::self()->instance( \
m_resourceId ) ); @@ -445,9 +445,9 @@ void InvitationsAgent::collectionFetchResult( \
KJob *job )  
 void InvitationsAgent::collectionCreateResult( KJob *job )
 {
-  kDebug();
+  qDebug();
   if ( job->error() ) {
-    kWarning() << job->errorString();
+    qWarning() << job->errorString();
     emit status( AgentBase::Broken, i18n( "Failed to create collection: %1", \
job->errorString() ) );  if ( newAgentCreated )
       AgentManager::self()->removeInstance( AgentManager::self()->instance( \
m_resourceId ) ); @@ -466,11 +466,11 @@ Item InvitationsAgent::handleContent( const \
QString &vcal,  KCalCore::ICalFormat format;
   KCalCore::ScheduleMessage::Ptr message = format.parseScheduleMessage( calendar, \
vcal );  if ( !message ) {
-    kWarning() << "Invalid invitation:" << vcal;
+    qWarning() << "Invalid invitation:" << vcal;
     return Item();
   }
 
-  kDebug() << "id=" << item.id() << "remoteId=" << item.remoteId() << "vcal=" << \
vcal; +  qDebug() << "id=" << item.id() << "remoteId=" << item.remoteId() << "vcal=" \
<< vcal;  
   KCalCore::Incidence::Ptr incidence = \
message->event().staticCast<KCalCore::Incidence>();  Q_ASSERT( incidence );
@@ -489,11 +489,11 @@ Item InvitationsAgent::handleContent( const QString &vcal,
 
 void InvitationsAgent::itemAdded( const Item &item, const Collection &collection )
 {
-  kDebug() << item.id() << collection;
+  qDebug() << item.id() << collection;
   Q_UNUSED( collection );
 
   if ( !m_invitationsCollection->defaultCollection().isValid() ) {
-    kDebug() << "No default collection found";
+    qDebug() << "No default collection found";
     return;
   }
 
@@ -501,7 +501,7 @@ void InvitationsAgent::itemAdded( const Item &item, const \
Collection &collection  return;
 
   if ( !item.hasPayload<KMime::Message::Ptr>() ) {
-    kDebug() << "Item has no payload";
+    qDebug() << "Item has no payload";
     return;
   }
 
@@ -513,20 +513,20 @@ void InvitationsAgent::itemAdded( const Item &item, const \
Collection &collection  
   KCalCore::MemoryCalendar::Ptr calendar( new KCalCore::MemoryCalendar( \
KSystemTimeZones::local() ) );  if ( message->contentType()->isMultipart() ) {
-    kDebug() << "message is multipart:" << message->attachments().size();
+    qDebug() << "message is multipart:" << message->attachments().size();
 
     InvitationsAgentItem *it = 0;
     foreach ( KMime::Content *content, message->contents() ) {
 
       KMime::Headers::ContentType *ct = content->contentType();
       Q_ASSERT( ct );
-      kDebug() << "Mimetype of the body part is " << ct->mimeType();
+      qDebug() << "Mimetype of the body part is " << ct->mimeType();
       if ( ct->mimeType() != "text/calendar" )
         continue;
 
       Item newItem = handleContent( QLatin1String(content->body()), calendar, item \
);  if ( !newItem.hasPayload() ) {
-        kDebug() << "new item has no payload";
+        qDebug() << "new item has no payload";
         continue;
       }
 
@@ -536,19 +536,19 @@ void InvitationsAgent::itemAdded( const Item &item, const \
Collection &collection  it->add( newItem );
     }
   } else {
-    kDebug() << "message is not multipart";
+    qDebug() << "message is not multipart";
 
     KMime::Headers::ContentType *ct = message->contentType();
     Q_ASSERT( ct );
-    kDebug() << "Mimetype of the body is " << ct->mimeType();
+    qDebug() << "Mimetype of the body is " << ct->mimeType();
     if ( ct->mimeType() != "text/calendar" )
       return;
 
-    kDebug() << "Message has an invitation in the body, processing";
+    qDebug() << "Message has an invitation in the body, processing";
 
     Item newItem = handleContent( QLatin1String(message->body()), calendar, item );
     if ( !newItem.hasPayload() ) {
-      kDebug() << "new item has no payload";
+      qDebug() << "new item has no payload";
       return;
     }
 
diff --git a/resources/pop3/accountdialog.cpp b/resources/pop3/accountdialog.cpp
index 91d3baf..d4e9932 100644
--- a/resources/pop3/accountdialog.cpp
+++ b/resources/pop3/accountdialog.cpp
@@ -259,11 +259,11 @@ void AccountDialog::walletOpenedForLoading( bool success )
       passwordEdit->setText( password );
       mInitalPassword = password;
     } else {
-      kWarning() << "Wallet not open or doesn't have pop3 folder.";
+      qWarning() << "Wallet not open or doesn't have pop3 folder.";
     }
   }
   else {
-    kWarning() << "Failed to open wallet for loading the password.";
+    qWarning() << "Failed to open wallet for loading the password.";
   }
 
   const bool walletError = !success || !mWallet->isOpen();
@@ -295,12 +295,12 @@ void AccountDialog::walletOpenedForSaving( bool success )
       mParentResource->clearCachedPassword();
     }
     else {
-      kWarning() << "Wallet not open.";
+      qWarning() << "Wallet not open.";
     }
   }
   else {
     // Should we alert the user here?
-    kWarning() << "Failed to open wallet for saving the password.";
+    qWarning() << "Failed to open wallet for saving the password.";
   }
 
   delete mWallet;
@@ -378,12 +378,12 @@ void AccountDialog::slotPipeliningClicked()
 
 void AccountDialog::slotPopEncryptionChanged( int id )
 {
-  kDebug() << "setting port";
+  qDebug() << "setting port";
   // adjust port
   if ( id == Transport::EnumEncryption::SSL || portEdit->value() == 995 )
     portEdit->setValue( ( id == Transport::EnumEncryption::SSL ) ? 995 : 110 );
 
-  kDebug() << "port set ";
+  qDebug() << "port set ";
   enablePopFeatures(); // removes invalid auth options from the combobox
 }
 
@@ -617,13 +617,13 @@ void AccountDialog::saveSettings()
 
   if ( ( !passwordEdit->text().isEmpty() && userChangedPassword ) ||
        userWantsToDeletePassword ) {
-    kDebug() << mWallet <<  mWallet->isOpen();
+    qDebug() << mWallet <<  mWallet->isOpen();
     if ( mWallet && mWallet->isOpen() ) {
       // wallet is already open
       walletOpenedForSaving( true );
     } else {
       // we need to open the wallet
-      kDebug() << "we need to open the wallet";
+      qDebug() << "we need to open the wallet";
       mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winId(),
                                     Wallet::Asynchronous );
       if ( mWallet ) {
diff --git a/resources/pop3/jobs.cpp b/resources/pop3/jobs.cpp
index a29f1f6..abbd914 100644
--- a/resources/pop3/jobs.cpp
+++ b/resources/pop3/jobs.cpp
@@ -46,7 +46,7 @@ void POPSession::slotSlaveError( KIO::Slave *slave , int errorCode,
                                  const QString &errorMessage )
 {
   Q_UNUSED( slave );
-  kWarning() << "Got a slave error:" << errorMessage;
+  qWarning() << "Got a slave error:" << errorMessage;
 
   if ( slave != mSlave )
     return;
@@ -231,7 +231,7 @@ void SlaveBaseJob::slotSlaveResult( KJob *job )
 void SlaveBaseJob::slotSlaveData( KIO::Job *job, const QByteArray &data )
 {
   Q_UNUSED( job );
-  kWarning() << "Got unexpected slave data:" << data.data();
+  qWarning() << "Got unexpected slave data:" << data.data();
 }
 
 void SlaveBaseJob::slaveError( int errorCode, const QString &errorMessage )
@@ -348,11 +348,11 @@ void ListJob::slotSlaveData( KIO::Job *job, const QByteArray \
&data )  if ( idIsNumber )
       mIdList.insert( id, length );
     else
-      kWarning() << "Got non-integer ID as part of the LIST response, ignoring"
+      qWarning() << "Got non-integer ID as part of the LIST response, ignoring"
                  << idString.data();
   }
   else {
-    kWarning() << "Got invalid LIST response:" << data.data();
+    qWarning() << "Got invalid LIST response:" << data.data();
   }
 }
 
@@ -383,8 +383,8 @@ void UIDListJob::slotSlaveData( KIO::Job *job, const QByteArray \
&data )  const int space = cleanData.indexOf( ' ' );
 
   if ( space <= 0 ) {
-    kWarning() << "Invalid response to the UIDL command:" << data.data();
-    kWarning() << "Ignoring this entry.";
+    qWarning() << "Invalid response to the UIDL command:" << data.data();
+    qWarning() << "Ignoring this entry.";
   }
   else {
     QByteArray idString = cleanData.left( space );
@@ -398,14 +398,14 @@ void UIDListJob::slotSlaveData( KIO::Job *job, const QByteArray \
&data )  mIdList.insert( uidQString, id );
       }
       else {
-        kWarning() << "Got invalid/empty UID from the UIDL command:"
+        qWarning() << "Got invalid/empty UID from the UIDL command:"
                    << uidString.data();
-        kWarning() << "The whole response was:" << data.data();
+        qWarning() << "The whole response was:" << data.data();
       }
     }
     else {
-      kWarning() << "Got invalid ID from the UIDL command:" << idString.data();
-      kWarning() << "The whole response was:" << data.data();
+      qWarning() << "Got invalid ID from the UIDL command:" << idString.data();
+      qWarning() << "The whole response was:" << data.data();
     }
   }
 }
diff --git a/resources/pop3/settings.cpp b/resources/pop3/settings.cpp
index b44ae5c..a92d8f0 100644
--- a/resources/pop3/settings.cpp
+++ b/resources/pop3/settings.cpp
@@ -28,7 +28,7 @@ class SettingsHelper
   public:
     SettingsHelper() : q( 0 ) {}
     ~SettingsHelper() {
-      kWarning() << q;
+      qWarning() << q;
       delete q;
       q = 0;
     }
@@ -77,7 +77,7 @@ void Settings::setPassword( const QString& password )
     wallet->setFolder( QLatin1String("pop3") );
     wallet->writePassword( mResourceId, password );
   } else {
-    kWarning() << "Unable to open wallet!";
+    qWarning() << "Unable to open wallet!";
   }
   delete wallet;
 }


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic
diff --git a/resources/pop3/pop3resource.cpp b/resources/pop3/pop3resource.cpp
index b146f2c..c8ea903 100644
--- a/resources/pop3/pop3resource.cpp
+++ b/resources/pop3/pop3resource.cpp
@@ -93,7 +93,7 @@ void POP3Resource::intervalCheckTriggered()
 {
   Q_ASSERT( mState == Idle );
   if ( isOnline() ) {
-    kDebug() << "Starting interval mail check.";
+    qDebug() << "Starting interval mail check.";
     startMailCheck();
     mIntervalCheckInProgress = true;
   } else {
@@ -130,14 +130,14 @@ void POP3Resource::configure( WId windowId )
 void POP3Resource::retrieveItems( const Akonadi::Collection &collection )
 {
   Q_UNUSED( collection );
-  kWarning() << "This should never be called, we don't have a collection!";
+  qWarning() << "This should never be called, we don't have a collection!";
 }
 
 bool POP3Resource::retrieveItem( const Akonadi::Item &item, const QSet<QByteArray> \
&parts )  {
   Q_UNUSED( item );
   Q_UNUSED( parts );
-  kWarning() << "This should never be called, we don't have any item!";
+  qWarning() << "This should never be called, we don't have any item!";
   return false;
 }
 
@@ -189,7 +189,7 @@ void POP3Resource::walletOpenedForSaving( bool success )
     }
   }
   else
-    kWarning() << "Unable to write the password to the wallet.";
+    qWarning() << "Unable to write the password to the wallet.";
 
   delete mWallet;
   mWallet = 0;
@@ -242,12 +242,12 @@ void POP3Resource::doStateStep()
   case Idle:
     {
       Q_ASSERT( false );
-      kWarning() << "State machine should not be called in idle state!";
+      qWarning() << "State machine should not be called in idle state!";
       break;
     }
   case FetchTargetCollection:
     {
-      kDebug() << "================ Starting state FetchTargetCollection \
=========="; +      qDebug() << "================ Starting state \
                FetchTargetCollection ==========";
       emit status( Running, i18n( "Preparing transmission from \"%1\".", name() ) );
       Collection targetCollection( Settings::self()->targetCollection() );
       if ( !targetCollection.isValid() ) {
@@ -269,7 +269,7 @@ void POP3Resource::doStateStep()
     }
   case Precommand:
     {
-      kDebug() << "================ Starting state Precommand \
====================="; +      qDebug() << "================ Starting state \
Precommand =====================";  if ( !Settings::self()->precommand().isEmpty() ) \
                {
         PrecommandJob *precommandJob = new PrecommandJob( \
Settings::self()->precommand(), this );  connect( precommandJob, \
SIGNAL(result(KJob*)), @@ -284,7 +284,7 @@ void POP3Resource::doStateStep()
     }
   case RequestPassword:
     {
-      kDebug() << "================ Starting state RequestPassword \
================"; +      qDebug() << "================ Starting state \
RequestPassword ================";  
       // Don't show any wallet or password prompts when we are unit-testing
       if ( !Settings::self()->unitTestPassword().isEmpty() ) {
@@ -324,7 +324,7 @@ void POP3Resource::doStateStep()
     }
   case Connect:
     {
-      kDebug() << "================ Starting state Connect \
========================"; +      qDebug() << "================ Starting state \
Connect ========================";  Q_ASSERT( !mPopSession );
       mPopSession = new POPSession( mPassword );
       connect( mPopSession, SIGNAL(slaveError(int,QString)),
@@ -334,7 +334,7 @@ void POP3Resource::doStateStep()
     }
   case Login:
     {
-      kDebug() << "================ Starting state Login \
=========================="; +      qDebug() << "================ Starting state \
Login ==========================";  
       LoginJob *loginJob = new LoginJob( mPopSession );
       connect( loginJob, SIGNAL(result(KJob*)),
@@ -344,7 +344,7 @@ void POP3Resource::doStateStep()
     }
   case List:
     {
-      kDebug() << "================ Starting state List \
==========================="; +      qDebug() << "================ Starting state \
List ===========================";  emit status( Running, i18n( "Fetching mail \
listing." ) );  ListJob *listJob = new ListJob( mPopSession );
       connect( listJob, SIGNAL(result(KJob*)),
@@ -354,7 +354,7 @@ void POP3Resource::doStateStep()
     break;
   case UIDList:
     {
-      kDebug() << "================ Starting state UIDList \
========================"; +      qDebug() << "================ Starting state \
UIDList ========================";  UIDListJob *uidListJob = new UIDListJob( \
mPopSession );  connect( uidListJob, SIGNAL(result(KJob*)),
                this, SLOT(uidListJobResult(KJob*)) );
@@ -363,7 +363,7 @@ void POP3Resource::doStateStep()
     break;
   case Download:
     {
-      kDebug() << "================ Starting state Download \
======================="; +      qDebug() << "================ Starting state \
Download =======================";  FetchJob *fetchJob = new FetchJob( mPopSession );
 
       // Determine which mails we want to download. Those are all mails which are
@@ -380,7 +380,7 @@ void POP3Resource::doStateStep()
         }
       }
       mIdsToDownload = idsToDownload;
-      kDebug() << "We are going to download" << mIdsToDownload.size() << "messages";
+      qDebug() << "We are going to download" << mIdsToDownload.size() << "messages";
 
       // For proper progress, the job needs to know the sizes of the messages, so
       // put them into a list here
@@ -401,8 +401,8 @@ void POP3Resource::doStateStep()
     break;
   case Save:
     {
-      kDebug() << "================ Starting state Save \
                ===========================";
-      kDebug() << mPendingCreateJobs.size() << "item create jobs are pending";
+      qDebug() << "================ Starting state Save \
==========================="; +      qDebug() << mPendingCreateJobs.size() << "item \
create jobs are pending";  if ( mPendingCreateJobs.size() > 0 )
         emit status( Running, i18n( "Saving downloaded messages." ) );
 
@@ -416,7 +416,7 @@ void POP3Resource::doStateStep()
     break;
   case Delete:
     {
-      kDebug() << "================ Starting state Delete \
========================="; +      qDebug() << "================ Starting state \
Delete =========================";  QList<int> idsToKill = idsToDelete();
       if ( !idsToKill.isEmpty() ) {
         emit status( Running, i18n( "Deleting messages from the server.") );
@@ -433,7 +433,7 @@ void POP3Resource::doStateStep()
     break;
   case Quit:
     {
-      kDebug() << "================ Starting state Quit \
==========================="; +      qDebug() << "================ Starting state \
Quit ===========================";  QuitJob *quitJob = new QuitJob( mPopSession );
       connect( quitJob, SIGNAL(result(KJob*)),
                this, SLOT(quitJobResult(KJob*)) );
@@ -442,11 +442,11 @@ void POP3Resource::doStateStep()
     break;
   case SavePassword:
     {
-      kDebug() << "================ Starting state SavePassword \
==================="; +      qDebug() << "================ Starting state \
SavePassword ===================";  if ( !mSavePassword )
         finish();
       else {
-        kDebug() << "Writing password back to the wallet.";
+        qDebug() << "Writing password back to the wallet.";
         emit status( Running, i18n( "Saving password to the wallet." ) );
         mWallet = Wallet::openWallet( Wallet::NetworkWallet(), winIdForDialogs(),
                                       Wallet::Asynchronous );
@@ -528,7 +528,7 @@ void POP3Resource::precommandResult( KJob *job )
 void POP3Resource::loginJobResult( KJob *job )
 {
   if ( job->error() ) {
-    kDebug() << job->error() << job->errorText();
+    qDebug() << job->error() << job->errorText();
     if ( job->error() == KIO::ERR_COULD_NOT_LOGIN )
       mAskAgain = true;
     cancelSync( i18n( "Unable to login to the server %1.", Settings::self()->host() \
) + @@ -549,7 +549,7 @@ void POP3Resource::listJobResult( KJob *job )
     ListJob *listJob = dynamic_cast<ListJob*>( job );
     Q_ASSERT( listJob );
     mIdsToSizeMap = listJob->idList();
-    kDebug() << "IdsToSizeMap:" << mIdsToSizeMap;
+    qDebug() << "IdsToSizeMap:" << mIdsToSizeMap;
     advanceState( UIDList );
   }
 }
@@ -565,8 +565,8 @@ void POP3Resource::uidListJobResult( KJob *job )
     Q_ASSERT( listJob );
     mIdsToUidsMap = listJob->uidList();
     mUidsToIdsMap = listJob->idList();
-    kDebug() << "IdToUidMap:" << mIdsToUidsMap;
-    kDebug() << "UidToIdMap:" << mUidsToIdsMap;
+    qDebug() << "IdToUidMap:" << mIdsToUidsMap;
+    qDebug() << "UidToIdMap:" << mUidsToIdsMap;
 
     mUidListValid = !mIdsToUidsMap.isEmpty() || mIdsToSizeMap.isEmpty();
     if ( Settings::self()->leaveOnServer() && !mUidListValid ) {
@@ -591,10 +591,10 @@ void POP3Resource::fetchJobResult( KJob *job )
     return;
   }
   else {
-    kDebug() << "Downloaded" << mDownloadedIDs.size() << "mails";
+    qDebug() << "Downloaded" << mDownloadedIDs.size() << "mails";
 
     if ( !mIdsToDownload.isEmpty() ) {
-      kWarning() << "We did not download all messages, there are still some \
remaining " +      qWarning() << "We did not download all messages, there are still \
                some remaining "
                     "IDs, even though we requested their download:" << \
mIdsToDownload;  }
 
@@ -610,7 +610,7 @@ void POP3Resource::messageFinished( int messageId, \
KMime::Message::Ptr message )  return;
   }
 
-  //kDebug() << "Got message" << messageId
+  //qDebug() << "Got message" << messageId
   //         << "with subject" << message->subject()->asUnicodeString();
 
   Akonadi::Item item;
@@ -693,7 +693,7 @@ void POP3Resource::itemCreateJobResult( KJob *job )
   Q_ASSERT( idOfMessageJustCreated != -1 );
   mPendingCreateJobs.remove( createJob );
   mIDsStored.append( idOfMessageJustCreated );
   //kDebug() << "Just stored message with ID" << idOfMessageJustCreated
   //         << "on the Akonadi server";
 
   // Have all create jobs finished? Go to the next state, then
@@ -755,7 +755,7 @@ QList<int> POP3Resource::idsToDelete() const
           idsToSave.append( idToDelete );
         }
         else {
-          kDebug() << "Message" << idToDelete << "is too old and will be deleted.";
+          qDebug() << "Message" << idToDelete << "is too old and will be deleted.";
         }
       }
     }
@@ -808,7 +808,7 @@ QList<int> POP3Resource::idsToDelete() const
     }
   }
 
-  kDebug() << "Going to delete" << idsToDeleteFromServer.size() << \
idsToDeleteFromServer; +  qDebug() << "Going to delete" << \
idsToDeleteFromServer.size() << idsToDeleteFromServer;  return idsToDeleteFromServer;
 }
 
@@ -835,7 +835,7 @@ void POP3Resource::deleteJobResult( KJob *job )
       int index = seenUIDs.indexOf( deletedUID );
       if ( index != -1 ) {
         // TEST
-        kDebug() << "Removing UID" << deletedUID << "from the seen UID list, as it \
was deleted."; +        qDebug() << "Removing UID" << deletedUID << "from the seen \
UID list, as it was deleted.";  seenUIDs.removeAt( index );
         timeOfSeenUids.removeAt( index );
       }
@@ -850,7 +850,7 @@ void POP3Resource::deleteJobResult( KJob *job )
 
 void POP3Resource::finish()
 {
-  kDebug() << "================= Mail check finished. \
============================="; +  qDebug() << "================= Mail check \
finished. =============================";  saveSeenUIDList();
   if ( !mIntervalCheckInProgress )
     collectionsRetrieved( Akonadi::Collection::List() );
@@ -877,7 +877,7 @@ void POP3Resource::quitJobResult( KJob *job )
 
 void POP3Resource::slotSessionError( int errorCode, const QString &errorMessage )
 {
-  kWarning() << "Error in our session, unrelated to a currently running job!";
+  qWarning() << "Error in our session, unrelated to a currently running job!";
   cancelSync( KIO::buildErrorString( errorCode, errorMessage ) );
 }
 
@@ -934,13 +934,13 @@ void POP3Resource::saveSeenUIDList()
     }
   }
   else
-    kWarning() << "UID list from server is not valid.";
+    qWarning() << "UID list from server is not valid.";
 
 
   //
   // Now save it in the settings
   //
-  kDebug() << "The seen UID list has" << seenUIDs.size() << "entries";
+  qDebug() << "The seen UID list has" << seenUIDs.size() << "entries";
   Settings::self()->setSeenUidList( seenUIDs );
   Settings::self()->setSeenUidTimeList( timeOfSeenUIDs );
   Settings::self()->save();
@@ -950,11 +950,11 @@ void POP3Resource::cancelSync( const QString &errorMessage, \
bool error )  {
   if ( error ) {
     cancelTask( errorMessage );
-    kWarning() << "============== ERROR DURING POP3 SYNC \
                ==========================";
-    kWarning() << errorMessage;
+    qWarning() << "============== ERROR DURING POP3 SYNC \
=========================="; +    qWarning() << errorMessage;
   }
   else {
-    kDebug() << "Canceled the sync, but no error.";
+    qDebug() << "Canceled the sync, but no error.";
     cancelTask();
   }
   saveSeenUIDList();
@@ -693,7 +693,7 @@ void POP3Resource::itemCreateJobResult( KJob *job )
   mPendingCreateJobs.remove( createJob );
   mIDsStored.append( idOfMessageJustCreated );
-  //kDebug() << "Just stored message with ID" << idOfMessageJustCreated
+  //qDebug() << "Just stored message with ID" << idOfMessageJustCreated
   //         << "on the Akonadi server";
 